package com.dgtly.member.service;

import com.dgtly.member.domain.MemberFollow;
import java.util.List;

/**
 * 会员关注Service接口
 * 
 * @author dgtly
 * @date 2020-02-13
 */
public interface IMemberFollowService 
{
    /**
     * 查询会员关注
     * 
     * @param id 会员关注ID
     * @return 会员关注
     */
    public MemberFollow selectMemberFollowById(Long id);

    /**
     * 查询会员关注列表
     * 
     * @param memberFollow 会员关注
     * @return 会员关注集合
     */
    public List<MemberFollow> selectMemberFollowList(MemberFollow memberFollow);

    /**
     * 新增会员关注
     * 
     * @param memberFollow 会员关注
     * @return 结果
     */
    public int insertMemberFollow(MemberFollow memberFollow);

    /**
     * 修改会员关注
     * 
     * @param memberFollow 会员关注
     * @return 结果
     */
    public int updateMemberFollow(MemberFollow memberFollow);

    /**
     * 批量删除会员关注
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteMemberFollowByIds(String ids);

    /**
     * 删除会员关注信息
     * 
     * @param id 会员关注ID
     * @return 结果
     */
    public int deleteMemberFollowById(Long id);

    /**
     * @descption: 获取网站用户关注的商户列表
     * @param:
     * @return:
     * @auther: LiuLingChao
     * @date: 2020-2-27 15:53
     */
    public List<MemberFollow> getMemberFollowList(MemberFollow memberFollow);

    /**
     * @descption: 根据公司ID和 用户id取消关注
     * @param:
     * @return:
     * @auther: qxp
     * @date: 2020/3/3 16:46
     */
    public int deleteMemberFollowByCompanyMemberId(String memberId, String companyId);
}
